// src/common/data/diff.ts
function diffObjects(obj, newObj, options = { cyclesFix: true }, _stack = []) {
  let diffs = [];
  const isObjArray = Array.isArray(obj);
  for (const key in obj) {
    const objValue = obj[key];
    const path = isObjArray ? +key : key;
    if (!(key in newObj)) {
      diffs.push({
        type: "del",
        path: [path]
      });
      continue;
    }
    const newValue = newObj[key];
    const areObjects = typeof objValue === "object" && typeof newValue === "object";
    if (objValue && newValue && areObjects && !["Date", "RegExp", "String", "Number"].includes(Object.getPrototypeOf(objValue).constructor.name) && (options.cyclesFix ? !_stack.includes(objValue) : true)) {
      const nestedDiffs = diffObjects(
        objValue,
        newValue,
        options,
        options.cyclesFix ? _stack.concat([objValue]) : []
      );
      diffs = [...diffs, ...nestedDiffs.map((difference) => {
        difference.path.unshift(path);
        return difference;
      })];
    } else if (objValue !== newValue && !(areObjects && (Number.isNaN(objValue) ? `${objValue}` === `${newValue}` : +objValue === +newValue))) {
      diffs.push({
        path: [path],
        type: "upd",
        value: newValue
      });
    }
  }
  const isNewObjArray = Array.isArray(newObj);
  for (const key in newObj) {
    if (!(key in obj)) {
      diffs.push({
        type: "new",
        path: [isNewObjArray ? +key : key],
        value: newObj[key]
        // works for both array and record, only TS doesn't know ;)
      });
    }
  }
  return diffs;
}

export {
  diffObjects
};
//# sourceMappingURL=chunk-DGP32WEQ.js.map