import {
  createDecoder,
  readAny,
  readFloat32,
  readUint16,
  readUint32,
  readUint8,
  readUint8Array,
  readVarInt,
  readVarString,
  readVarUint,
  readVarUint8Array
} from "./chunk-IL77OGRC.js";
import {
  createBinEncoder,
  encodeToUint8Array,
  length,
  writeAny,
  writeFloat32,
  writeUint16,
  writeUint32,
  writeUint8,
  writeUint8Array,
  writeVarInt,
  writeVarString,
  writeVarUint,
  writeVarUint8Array
} from "./chunk-CYALHTOQ.js";
import {
  assertCondition
} from "./chunk-M6NJWFDP.js";
import {
  toUint8Array
} from "./chunk-EJGW3W3K.js";

// src/common/bin/index.ts
var BinaryEncoder = class {
  async encode(data) {
    const dataEncoder = createBinEncoder();
    writeAny(dataEncoder, data);
    return encodeToUint8Array(dataEncoder);
  }
  async decode(data) {
    return readAny(createDecoder(toUint8Array(data)));
  }
};
function encodeJson(data) {
  const dataEncoder = createBinEncoder();
  writeAny(dataEncoder, data);
  return encodeToUint8Array(dataEncoder);
}
function decodeJson(data) {
  return readAny(createDecoder(toUint8Array(data)));
}
function createBinaryStreamEncoder(initialData) {
  const dataEncoder = createBinEncoder();
  if (initialData != null)
    writeUint8Array(dataEncoder, toUint8Array(initialData));
  return {
    /** Just writes the bytes. Length is not stored! */
    writeBytes: (data, expectedLength) => {
      const bin = toUint8Array(data);
      assertCondition(!(expectedLength != null && bin.length !== expectedLength), `Expected ${expectedLength} bytes, got ${bin.length}`);
      writeUint8Array(dataEncoder, bin);
    },
    writeBytesVar: (data) => writeVarUint8Array(dataEncoder, toUint8Array(data)),
    writeUintVar: (data) => writeVarUint(dataEncoder, data),
    writeUint8: (data) => writeUint8(dataEncoder, data),
    writeUint16: (data) => writeUint16(dataEncoder, data),
    writeUint32: (data) => writeUint32(dataEncoder, data),
    writeIntVar: (data) => writeVarInt(dataEncoder, data),
    writeFloat: (data) => writeFloat32(dataEncoder, data),
    writeStringVar: (data) => writeVarString(dataEncoder, data),
    write: (data) => writeAny(dataEncoder, data),
    getUint8Array: () => encodeToUint8Array(dataEncoder),
    getLength: () => length(dataEncoder)
  };
}
function createBinaryStreamDecoder(data) {
  const dataDecoder = createDecoder(toUint8Array(data));
  return {
    readBytes: (len) => readUint8Array(dataDecoder, len),
    readBytesVar: () => readVarUint8Array(dataDecoder),
    readUintVar: () => readVarUint(dataDecoder),
    readUint8: () => readUint8(dataDecoder),
    readUint16: () => readUint16(dataDecoder),
    readUint32: () => readUint32(dataDecoder),
    readIntVar: () => readVarInt(dataDecoder),
    readFloat: () => readFloat32(dataDecoder),
    readStringVar: () => readVarString(dataDecoder),
    read: () => readAny(dataDecoder),
    getOffset: () => dataDecoder.pos || 0
  };
}
function bitfield(bitfield2 = 0) {
  return {
    setBit: (bit, value = true) => value ? bitfield2 |= 1 << bit : bitfield2 &= ~(1 << bit),
    unsetBit: (bit) => bitfield2 &= 1 << bit,
    toggleBit: (bit) => bitfield2 ^= 1 << bit,
    getBit: (bit) => (bitfield2 & 1 << bit) !== 0,
    getValue: () => bitfield2
  };
}
async function blobToArrayBuffer(blob) {
  return await blob.arrayBuffer();
}
async function blobToUint8Array(blob) {
  const buffer = await blobToArrayBuffer(blob);
  if (buffer != null)
    return toUint8Array(buffer);
}

export {
  BinaryEncoder,
  encodeJson,
  decodeJson,
  createBinaryStreamEncoder,
  createBinaryStreamDecoder,
  bitfield,
  blobToArrayBuffer,
  blobToUint8Array
};
//# sourceMappingURL=chunk-FDYG4H6L.js.map