import "../chunk-KDP637GO.js";
import "../chunk-A4L4FO52.js";
import "../chunk-NEEIRLS6.js";
import "../chunk-WZDTE5W3.js";
import "../chunk-VBSEGKT7.js";
import "../chunk-Q3QHD23G.js";
import "../chunk-CYDFP47V.js";
import "../chunk-URTIMVUU.js";
import "../chunk-DXM327S3.js";
import "../chunk-2VA3UGW7.js";
import "../chunk-5OVSRAPG.js";
import "../chunk-NLNCD3ES.js";
import "../chunk-BMLTMNZA.js";
import "../chunk-7QYVSWCZ.js";
import {
  useDefer,
  useDispose
} from "../chunk-VI7IQ5ZG.js";
import "../chunk-TSCDX4AS.js";
import "../chunk-AN7WCP7S.js";
import "../chunk-D6B6MYVG.js";
import {
  DefaultLogger
} from "../chunk-2DAGZ4FT.js";
import "../chunk-3MLDC2KV.js";
import "../chunk-7G6NITL4.js";
import "../chunk-RSLTBO5X.js";
import "../chunk-I45WP5PM.js";
import "../chunk-MIZOLME5.js";
import "../chunk-AKLYUMQO.js";
import "../chunk-YX6CL4KH.js";
import "../chunk-ZFRTRIT4.js";
import "../chunk-CFICINSP.js";
import "../chunk-3KKFLSLG.js";
import "../chunk-PLBFBDKH.js";
import "../chunk-2H4XRKWS.js";
import "../chunk-WJUQ3VXF.js";
import "../chunk-O4GTSXBN.js";
import "../chunk-2OUSR2BE.js";
import "../chunk-ZDZ4EQHN.js";
import "../chunk-PZP2B3FC.js";
import "../chunk-NSJKG6AJ.js";
import "../chunk-XHPHUZE4.js";
import "../chunk-NRGUBMFA.js";
import "../chunk-H564H42Z.js";
import "../chunk-PE4JT3J7.js";
import "../chunk-FL5CT6MC.js";
import "../chunk-2HWPZ6ZE.js";
import "../chunk-LAWEUL6N.js";
import "../chunk-V5ZQ2SFQ.js";
import "../chunk-DGP32WEQ.js";
import "../chunk-EDNCPFSF.js";
import "../chunk-73CVRDI7.js";
import "../chunk-3KQS63H6.js";
import "../chunk-C7K2ID3C.js";
import {
  sleep
} from "../chunk-L324TYGN.js";
import "../chunk-5DS3NT57.js";
import "../chunk-HLRQ5H3N.js";
import "../chunk-UO7L7NBK.js";
import "../chunk-QUQRUDWG.js";
import "../chunk-ITJJZ6AV.js";
import "../chunk-QUKKMPRF.js";
import "../chunk-GY34N3KU.js";
import "../chunk-X56GIAWQ.js";
import "../chunk-PN34O4SN.js";
import "../chunk-UOAPXGA4.js";
import "../chunk-HJ22ULAI.js";
import "../chunk-EJGW3W3K.js";
import "../chunk-EAYWSLQT.js";
import {
  __callDispose,
  __using
} from "../chunk-I7BWSAN6.js";

// src/common/dispose-defer.spec.ts
var log = DefaultLogger("dispose-test");
describe("dispose", () => {
  it("should dispose correctly", async () => {
    const disposeCalls = [];
    const dispose = useDispose("a");
    const y = dispose.track({
      dispose() {
        disposeCalls.push(1);
      }
    });
    dispose.track(() => {
      disposeCalls.push(2);
    });
    const x = {
      async dispose() {
        disposeCalls.push(3);
      }
    };
    dispose.track(x);
    dispose.track();
    dispose.track(async () => {
      disposeCalls.push(4);
    });
    expect(disposeCalls).toEqual([]);
    expect(dispose.getSize()).toEqual(4);
    await dispose.untrack(x);
    expect(disposeCalls).toEqual([3]);
    expect(dispose.getSize()).toEqual(3);
    await dispose.untrack(x);
    expect(disposeCalls).toEqual([3]);
    expect(dispose.getSize()).toEqual(3);
    y?.();
    y?.();
    await dispose.untrack(x);
    expect(disposeCalls).toEqual([3, 1]);
    expect(dispose.getSize()).toEqual(2);
    await dispose.dispose();
    expect(disposeCalls).toEqual([3, 1, 4, 2]);
    expect(dispose.getSize()).toEqual(0);
    await dispose();
    expect(disposeCalls).toEqual([3, 1, 4, 2]);
    expect(dispose.getSize()).toEqual(0);
  });
  it("should be a fancy dispose itself", () => {
    let x = 1;
    class Some {
      constructor() {
        this.dispose = useDispose(log);
        this.dispose.track(() => {
          x = 2;
        });
      }
    }
    const obj = new Some();
    expect(x).toBe(1);
    void obj.dispose();
    expect(x).toBe(2);
  });
  it("should defer lifo", async () => {
    const stack = [];
    const defer = useDefer({ mode: "lifo" });
    defer.add(() => stack.push("a"));
    defer.add(() => stack.push("b"));
    defer.add(() => stack.push("c"));
    expect(stack).toEqual([]);
    void defer(true);
    expect(stack).toEqual(["c", "b", "a"]);
  });
  it("should defer fifo", async () => {
    const stack = [];
    const defer = useDefer({ mode: "fifo" });
    defer.add(() => stack.push("a"));
    defer.add(async () => stack.push("b"));
    defer.add(() => stack.push("c"));
    expect(stack).toEqual([]);
    await defer();
    expect(stack).toEqual(["a", "b", "c"]);
  });
  it("should dispose sync", async () => {
    const stack = [];
    const dispose = useDispose();
    dispose.add(() => stack.push("a"));
    dispose.add(() => stack.push("b"));
    dispose.add(() => stack.push("c"));
    expect(stack).toEqual([]);
    await dispose(true);
    expect(stack).toEqual(["c", "b", "a"]);
  });
  it("should dispose sync using using", async () => {
    const stack = [];
    function helper() {
      var _stack = [];
      try {
        const dispose = __using(_stack, useDispose());
        dispose.add(() => stack.push("a"));
        dispose.add(() => stack.push("b"));
        dispose.add(() => stack.push("c"));
        expect(stack).toEqual([]);
      } catch (_) {
        var _error = _, _hasError = true;
      } finally {
        __callDispose(_stack, _error, _hasError);
      }
    }
    helper();
    expect(stack).toEqual(["c", "b", "a"]);
  });
  it("should dispose sync 2", async () => {
    const stack = [];
    const dispose = useDispose();
    dispose.add(() => stack.push("a"));
    dispose.add(() => stack.push("b"));
    dispose.add(async () => {
      await sleep(1);
      stack.push("c");
    });
    expect(stack).toEqual([]);
    expect(dispose.sync).toThrowError();
  });
  it("should use using", async () => {
    const history = [];
    function log2(s) {
      history.push(s);
    }
    class TempFile {
      constructor(path) {
        log2("constructor");
      }
      [Symbol.dispose]() {
        log2("dispose");
      }
    }
    function fn() {
      var _stack = [];
      try {
        const f = __using(_stack, new TempFile("abc"));
        log2("fn return");
      } catch (_) {
        var _error = _, _hasError = true;
      } finally {
        __callDispose(_stack, _error, _hasError);
      }
    }
    log2("fn before");
    fn();
    log2("fn after");
    expect(history).toMatchInlineSnapshot(`
      Array [
        "fn before",
        "constructor",
        "fn return",
        "dispose",
        "fn after",
      ]
    `);
  });
});
//# sourceMappingURL=dispose-defer.spec.js.map