import { TimerExecFunction } from '../dispose-utils.js';
import { Disposer, DisposerFunction } from '../dispose-types.js';
import './emitter.js';
import { Channel } from './channel.js';
import '../global.js';
import '../log/log.js';
import '../log/log-console-original.js';
import '../dispose-defer.js';
import '../log/log-base.js';

/**
 * Channel that buffers if not connected.
 * The actual channel can be removed and replaced.
 */
declare class ResillientChannel extends Channel {
    private channel?;
    private buffer;
    dispose: ((strictSync?: boolean) => Promise<any> | void) & {
        disposed: number;
        add: (obj?: Disposer) => DisposerFunction | undefined;
        remove: (disposable: Disposer) => Promise<void> | void;
        track: (obj?: Disposer) => DisposerFunction | undefined;
        untrack: (disposable: Disposer) => Promise<void> | void;
        dispose: (strictSync?: boolean) => Promise<any> | void;
        disposeSync: () => void;
        sync: () => void;
        exec: (strictSync?: boolean) => Promise<any> | void;
        getSize(): number;
        isDisposed(): boolean;
        [Symbol.dispose](): void | Promise<any>;
        [Symbol.asyncDispose](): Promise<any>;
    } & {
        timeout: (fn: TimerExecFunction, timeout?: number) => DisposerFunction;
        interval: (fn: TimerExecFunction, interval?: number) => DisposerFunction;
        intervalPause: (fn: TimerExecFunction, interval?: number) => DisposerFunction;
        on: (emitter: any, eventName: string, fn: (ev?: any) => void, ...args: any[]) => DisposerFunction;
        once: (emitter: any, eventName: string, fn: (ev?: any) => void, ...args: any[]) => DisposerFunction;
    };
    private postMessageRaw;
    /** Post all buffered messages */
    flushBuffer(): void;
    /** Reset buffer without force sending */
    emptyBuffer(): void;
    /**
     * Set a new channel and flush buffer
     */
    setChannel(channel?: Channel): void;
    /** @deprecated use `setChannel(undefined)` */
    deleteChannel(): void;
    postMessage(data: Uint8Array | string): void;
    get isConnected(): boolean;
}

export { ResillientChannel };
