import {
  literal,
  number,
  object,
  string,
  union
} from "../../chunk-NCBOHAYI.js";
import "../../chunk-3KKFLSLG.js";
import "../../chunk-PLBFBDKH.js";
import "../../chunk-2H4XRKWS.js";
import "../../chunk-WJUQ3VXF.js";
import "../../chunk-O4GTSXBN.js";
import "../../chunk-2OUSR2BE.js";
import "../../chunk-ZDZ4EQHN.js";
import "../../chunk-PZP2B3FC.js";
import "../../chunk-NSJKG6AJ.js";
import "../../chunk-XHPHUZE4.js";
import "../../chunk-NRGUBMFA.js";
import "../../chunk-H564H42Z.js";
import "../../chunk-PE4JT3J7.js";
import "../../chunk-FL5CT6MC.js";
import "../../chunk-2HWPZ6ZE.js";
import "../../chunk-LAWEUL6N.js";
import "../../chunk-V5ZQ2SFQ.js";
import "../../chunk-DGP32WEQ.js";
import "../../chunk-EDNCPFSF.js";
import "../../chunk-73CVRDI7.js";
import "../../chunk-3KQS63H6.js";
import "../../chunk-C7K2ID3C.js";
import "../../chunk-L324TYGN.js";
import "../../chunk-5DS3NT57.js";
import "../../chunk-HLRQ5H3N.js";
import "../../chunk-UO7L7NBK.js";
import "../../chunk-QUQRUDWG.js";
import "../../chunk-ITJJZ6AV.js";
import "../../chunk-QUKKMPRF.js";
import "../../chunk-GY34N3KU.js";
import "../../chunk-X56GIAWQ.js";
import "../../chunk-PN34O4SN.js";
import {
  cloneJsonObject
} from "../../chunk-UOAPXGA4.js";
import "../../chunk-HJ22ULAI.js";
import "../../chunk-EJGW3W3K.js";
import "../../chunk-EAYWSLQT.js";
import "../../chunk-I7BWSAN6.js";

// src/common/schema/schema.spec.ts
describe("schema", () => {
  it("create schema", async () => {
    const schema = object({
      id: string().default(() => "123"),
      name: string(),
      age: number().optional(),
      obj: object({
        test: number()
      }).optional()
    });
    const sample = {
      name: "Hello",
      age: 42
    };
    expect(cloneJsonObject(schema)).toMatchInlineSnapshot(`
      Object {
        "_object": Object {
          "age": Object {
            "_optional": true,
            "type": "number",
          },
          "id": Object {
            "type": "string",
          },
          "name": Object {
            "type": "string",
          },
          "obj": Object {
            "_object": Object {
              "test": Object {
                "type": "number",
              },
            },
            "_optional": true,
            "type": "object",
          },
        },
        "type": "object",
      }
    `);
    expect(schema.parse(sample)).toMatchInlineSnapshot(`
      Object {
        "age": 42,
        "id": "123",
        "name": "Hello",
      }
    `);
  });
  it("union", async () => {
    const literals = [
      literal("one"),
      literal("two"),
      literal("three")
    ];
    const schema = object({
      id: string().default(() => "123").props({
        someProp: "someValue"
      }),
      literal: literal("demo"),
      name: union(literals)
    });
    const sample = {
      literal: "demo",
      name: "two"
    };
    expect(cloneJsonObject(schema)).toMatchInlineSnapshot(`
      Object {
        "_object": Object {
          "id": Object {
            "_props": Object {
              "someProp": "someValue",
            },
            "type": "string",
          },
          "literal": Object {
            "type": "string",
          },
          "name": Object {
            "_union": Array [
              Object {
                "type": "string",
              },
              Object {
                "type": "string",
              },
              Object {
                "type": "string",
              },
            ],
            "type": "string",
          },
        },
        "type": "object",
      }
    `);
    expect(schema.parse(sample)).toMatchInlineSnapshot(`
      Object {
        "id": "123",
        "literal": "demo",
        "name": "two",
      }
    `);
  });
});
//# sourceMappingURL=schema.spec.js.map